/*************************************************************************
 *
 *   Program:  PicoM_External.h					Version: 1.00
 *
 *   Author:  SS								Date:  Feb 27, 2014
 *
 *   This project is licensed under the MIT license.  You can modify, enhance, etc anyway you like.
 *
 *   SOC Robotics, Inc is not liable in anyway for the use of this software and assumes no responsibility 
 *   for it's use.  No warranties of any kind are provided.
 *
 *   Copyright 2014, SOC Robotics, Inc. 
 *   There maybe code from other parties in this application  If we don't mention them by name thank you
 *   and if we should please let us know and we will include your name and attribution.
*
 *************************************************************************/
#include "stm32f0xx.h"
//#include "stm32f0xx_conf.h"
//#include "stm32072b_eval.h"

#include "stdint.h"
#include "stdbool.h"
#include "stdio.h"
#include "math.h"
#include "string.h"
#include "stddef.h"
#include "stdlib.h"
#include "ctype.h"

#include "NRF24L01.h"
#include "PaellaM_Defines.h"

extern volatile float pi;
extern volatile double pi_d;

extern uint32_t topOfProcStack;

// 1 msec counters
extern volatile unsigned int mseccountdown1,mseccountdown2,mseccountdown3,bmp180countdown;
extern volatile unsigned long mseccounter;
extern volatile float elapsedtime;
extern volatile int usectimertally;  // Uses TIM7 to track long usec time periods
extern volatile bool usbconnected;

// RF24L01 parameters
extern volatile unsigned char TADDR[],payload[],rf_mode,rf_state,channel_no,rf_payload_size,device_id,rf_device_class;
extern volatile unsigned char deviceaddress[],messageBuf[];
extern volatile bool rf_inmessage;
extern volatile char rfbuf[];

extern volatile char spiflip,stepactive,ledflip,ledblink;
extern volatile char memsstate;
extern volatile unsigned char spidata[],spiavailable,blockptrhead,blockptrtail;
extern volatile unsigned int mseccountdown1,mseccountdown2,mseccountdown3;

// MPU9150 variables
extern volatile char mpu9150state;
extern volatile float magposition[],mpu9150_tempoffset;

// BMP180 variables
extern volatile unsigned char BMPstate,bmp180mode,bmp180tempstate,bmp180pressurestate,bmp180state;
extern volatile unsigned short int bmpac4,bmpac5,bmpac6,ibmptemperature,ibmppressure;
extern volatile short int  bmpac1,bmpac2,bmpac3,bmpb1,bmpb2,bmpmb,bmpmc,bmpmd;
extern volatile int  bmpskipcount;
extern volatile long b5;
extern volatile float bmppressure,bmptemperature,pressuremin,pressuremax,bmp180_tempoffset;
extern volatile float pressure,temperature;

// FXOS8700 6DOF 3-axis accelerometer, 3-axis magnetometer variables
extern volatile char fxos8700state;
extern volatile char pca9545channel[];
extern volatile int fingerindex,digitindex;

// MMA8653 3DOF accelerometer variables
extern volatile char mma8653state;

// SI7013 Humidity sensor variables
extern volatile char si7013state,si7013sample,si7013sampletarget;

// L3GD20 3DOF gyro sensor variables
extern volatile char l3gd20state;

// ADPS-9007 light sensor variables
extern volatile char adps9007state;

// Display configuration parameters - this is set at init time
extern volatile char updatedisplay;
extern volatile int updaterate;

// Special functions
extern char *ftoa(float num,int precision,int numchars);

// General Functions
extern unsigned char getnwchar(void);
extern void PutChar(unsigned char inchar);
extern unsigned char GetChar(void);
//extern void Delaymsec(unsigned int delay);
//extern void Delayusec(unsigned int delay);
//extern void Start_TCC4_Pulse(void);
//extern void StartTimer_Coarse(void);
//extern void StartTimer_Fine(void);
//extern float StopTimer_Coarse(void);
//extern float StopTimer_Fine(void);
extern void LED(char select,char mode);
extern unsigned long StartTimer(void);
extern float ElapsedTimesec(unsigned long starttime);
extern long ElapsedTimeusec(void);
extern void TIM7_Start(void);
extern void TIM7_Stop(void);
extern void delay_us(unsigned int ult);
extern void delay_ms(unsigned int ult);

/*****************************************************************
   USART3 Interrupt driver serial functions -
*****************************************************************/
extern int GetCharnw2(void);
extern unsigned char GetChar2(void);
extern void PutChar2(unsigned char outchar);
extern void Puts2(unsigned char *outstrg);
extern int printf2(const char *fmt, ...);
extern int scanf2(const char *fmt, ...);

/*****************************************************************
   TWI Functions
*****************************************************************/
extern uint8_t I2C_WriteBytes(I2C_TypeDef* I2Cx,uint8_t twiaddress,uint8_t nbytes);
extern uint8_t I2C_ReadBytes(I2C_TypeDef* I2Cx,uint8_t twiaddress,uint8_t nbytes);

extern volatile unsigned char TWI_Write(volatile unsigned char address, volatile unsigned char *msg, volatile unsigned char msgSize);
extern volatile unsigned char TWI_Start_Read(volatile unsigned char address, volatile unsigned char msgSize);
extern volatile unsigned char TWI_Get_Data_From_Transceiver(volatile unsigned char *msg, volatile unsigned char msgSize);
extern volatile unsigned char twim_probe(I2C_TypeDef* I2Cx,uint32_t chip_addr);

/*****************************************************************
   SPI functions
*****************************************************************/
extern uint8_t SPI1_transfer_byte(uint8_t byte);
extern uint8_t SPI2_transfer_byte(uint8_t byte);

/*****************************************************************
   General Purpose MEMs sensor functions
*****************************************************************/
extern void MEMS_Sensor_Update(void);

/*****************************************************************
   NRF24L01 Wireless Communications Processor Functions
*****************************************************************/
extern void RF24L01_Test(void);
extern void rf24L01_Init(volatile char rftype);
extern bool RF24L01_Process_Commands(void);
extern int RF24L01_Enumeration(char mode);
extern void RF_DumpRegisters(int mode);
extern void RF_GetAll_IMU8420_Data(void);
extern void Display_RF_Status(void);
extern volatile uint8_t RF_GetStatus(void);
extern void Check_RF_Connection(void);

/*****************************************************************
   BMP180 Barometer Functions
*****************************************************************/
extern void Init_BMP180_Readings(void);
extern unsigned char Read_BMP180_EEPROM(unsigned char eepromaddress);
extern short int Read_BMP180_EEPROM_Signed(unsigned char eepromaddress);
extern unsigned short int Read_BMP180_EEPROM_UnSigned(unsigned char eepromaddress);
extern void Load_BMP180_Parameters(void);
extern unsigned short int Finish_Read_BMP180_Pressure(void);
extern float Finish_Read_BMP085_Pressurefloat(void);
extern unsigned short int Read_BMP180_Pressure(void);
extern float Read_BMP085_pressurefloat(char mode);
extern void Start_Read_BMP180_Temperature(void);
extern unsigned short int Finish_Read_BMP180_Temperature(void);
extern void Check_BMP180_Update(void);
extern unsigned short int Read_BMP180_Temperature(void);
extern void Enumerate_TWI_Devices(char mode);
extern float CalculateBMP180Temperature(unsigned int BMPtemperature);
extern float CalculateBMP180pressurefloat(unsigned int BMPtemperature,unsigned int BMPpressure);
extern void DisplayBMP180Brief(char mode);
extern void BMP180_PrintData(void);

/*****************************************************************
   MPU-9150 9DOF sensor Functions
*****************************************************************/
extern void MPU9150_Test(void);
extern void MPU9150_Init(void);
extern volatile int MPU9150_ReadSensor(volatile int addrL, volatile int addrH);
extern volatile unsigned char MPU9150_ReadSensor2(volatile unsigned char addr);
extern volatile int MPU9150_WriteSensor(volatile int addr,volatile int data);
extern void MPU9150_SetupCompass(void);
extern void MPU9150_Setup(void);
extern void MPU9150_Read_Mag(void);
extern void MPU9150_Read_Accel(void);
extern void MPU9150_Read_Gyro(void);
extern void MPU9150_Read_Temp(void);
extern void Calculate_Roll_Pitch_Yaw(void);
extern void MPU9150_Data_Read(void);
extern void Get_9DOFMEMsData(volatile char mode);
extern void Get_10DOFMEMsData(volatile char mode);
extern void Enumerate_MPU9150(void);


/*****************************************************************
   EEPROM Functions
*****************************************************************/
extern int EEPROM_Read_Int(unsigned char ptr);
extern void EEPROM_Write_Int(unsigned char ptr,int value);
extern float EEPROM_Read_Float(unsigned char ptr);
extern void EEPROM_Write_Float(unsigned char ptr,float value);
extern void EEPROM_LoadParameters(void);
extern void EEPROM_StoreParameters(void);
extern void EEPROM_WriteSignature(void);
extern int EEPROM_CheckSignature(void);
extern void EEPROM_Printf(void);

/*****************************************************************
   FXOS8700 6DOF acceleromer/magnetormeter Functions
*****************************************************************/
extern unsigned char FXOS8700_Read_Register(unsigned char address,unsigned char register);
extern void FXOS8700_Read_Multibyte(unsigned char address,unsigned char registerid,unsigned char *buffer,int bytes);
extern unsigned char FXOS8700_Write_Register(I2C_TypeDef* I2Cx,unsigned char address,unsigned char registerid,unsigned char regvalue);
extern int FXOS8700CQ_Init(I2C_TypeDef* I2Cx,unsigned char address);
extern unsigned char FXOS8700CQ_Accel_Mag(I2C_TypeDef* I2Cx,unsigned char address);
extern void FXOS8700_Find(I2C_TypeDef* I2Cx);
extern void FXOS8700_Init_Chain(I2C_TypeDef* I2Cx);
extern void FXOS8700_Init_All(char mode);
extern void FXOS8700_Display_All(char mode);
extern void PCA9540_ChannelSelect(unsigned char channel);

/*****************************************************************
   MMA8653 3DOF Accelerometer Functions
*****************************************************************/

/*****************************************************************
   SI7013 Humidity/Temperature Functions
*****************************************************************/
extern void SI7013_Test(void);
extern void Enumerate_SI7013(void);
extern unsigned char SI7013_Read_Register(unsigned char address,unsigned char reg);
extern volatile unsigned int SI7013_Read_Word(unsigned char address);
extern unsigned int SI7013_Read_Register_Word(unsigned char address,unsigned char reg);
extern void SI7013_Read_Register_Numbytes(unsigned char address,unsigned char reg,int numbytes);
extern void SI7013_Read_Numbytes(unsigned char address,int numbytes);
extern void SI7013_Write_Register(unsigned char address,unsigned char reg);
extern void SI7013_Write_Register_Value(unsigned char address,unsigned char reg,unsigned char regvalue);
extern volatile void SI7013_ReadHumidity(void);
extern volatile void SI7013_ReadTemp(void);

/*****************************************************************
   APDS-9007 Light sensor Functions
*****************************************************************/

/*****************************************************************
   ST7735 Functions
*****************************************************************/
extern void setAddrWindow(unsigned char x0, unsigned char y0, unsigned char x1, unsigned char y1);
extern void ST7735_pushColor(unsigned int color); // for what?
extern void ST7735_drawPixel(unsigned char x, unsigned char y, unsigned int color);
extern void ST7735_fillScreen(unsigned int color);
extern void ST7735_InitB(void); // not used
extern void ST7735_InitR(void); // initialize a ST7735 chip
extern void ST7735_drawString(volatile unsigned char x, volatile unsigned char y, char *c, volatile unsigned int color, volatile unsigned char size);
extern void ST7735_drawChar(unsigned char x, unsigned char y, char c, unsigned int color, unsigned char size);
extern void ST7735_fillCircle(unsigned char x0, unsigned char y0, unsigned char r, unsigned int color);
extern void ST7735_drawCircle(unsigned char x0, unsigned char y0, unsigned char r, unsigned int color);
extern void ST7735_setRotation(unsigned char m);
extern void ST7735_drawRect(unsigned char x, unsigned char y, unsigned char w, unsigned char h, unsigned int color);
extern void ST7735_fillRect(unsigned char x, unsigned char y, unsigned char w, unsigned char h, unsigned int color);
extern void ST7735_drawVerticalLine(unsigned char x, unsigned char y, unsigned char length, unsigned int color);
extern void ST7735_drawHorizontalLine(unsigned char x, unsigned char y, unsigned char length, unsigned int color);
extern void ST7735_drawFastLine(unsigned char x, unsigned char y, unsigned char length, unsigned int color, unsigned char rotflag);
extern void ST7735_drawLine(int x0, int y0, int x1, int y1, unsigned int color);
extern volatile unsigned char ST7735_getRotation(void);
//extern volatile uint16_t colorsRGB24toRGB565(volatile uint8_t r, volatile uint8_t g, volatile uint8_t b)

/*****************************************************************
   SSD1306 Functions
*****************************************************************/
extern void ssd1306_Init(void);
extern void ssd1306_clear(uint8_t value);
extern void ssd1306_putbigfloat(int row,int col,float num,int digits,int decimal);
extern void ssd1306_putbigdigit(int row,int col,int num,int digits);
extern void SSD1306_Test(void);
extern void ssd1306_printfs(int row, int col, char *inchar);
extern int ssd1306_printf(int row, int col, const char *fmt, ...);

